@@ -498,6 +498,10 @@ class WorkflowTools(object):
                     for site, status, drain in sitereadiness.i_site_readiness() \
                     if not site.startswith('T3')
                 ]
+
+        except Exception as e:
+            print(e)
+            self.site_statuses = [ {'site':'all' , 'status':'the server is down' , 'drain':'server is down'} ]
         finally:
             self.readinesslock.release()
 
